==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/GridCellEditStartedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridCellEditStartedEventArgsDescription } from "./GridCellEditStartedEventArgsDescription";
/**
 * @hidden
 */
var GridCellEditStartedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridCellEditStartedEventArgsDescriptionMetadata, _super);
    function GridCellEditStartedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellEditStartedEventArgsDescriptionMetadata.b = function (a) {
        if (GridCellEditStartedEventArgsDescriptionMetadata.a == null) {
            GridCellEditStartedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellEditStartedEventArgsDescriptionMetadata.c(GridCellEditStartedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridCellEditStartedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridCellEditStartedEventArgsDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    GridCellEditStartedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("Row", "Number:int");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    GridCellEditStartedEventArgsDescriptionMetadata.d = function (a) {
        GridCellEditStartedEventArgsDescriptionMetadata.b(a);
        a.aa("GridCellEditStartedEventArgs", function () { return new GridCellEditStartedEventArgsDescription(); });
        a.z("GridCellEditStartedEventArgs", GridCellEditStartedEventArgsDescriptionMetadata.a);
    };
    GridCellEditStartedEventArgsDescriptionMetadata.$t = markType(GridCellEditStartedEventArgsDescriptionMetadata, 'GridCellEditStartedEventArgsDescriptionMetadata');
    GridCellEditStartedEventArgsDescriptionMetadata.a = null;
    return GridCellEditStartedEventArgsDescriptionMetadata;
}(Base));
export { GridCellEditStartedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridCellEditStartedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridCellEditStartedEventArgsDescription } from "./GridCellEditStartedEventArgsDescription";
/**
 * @hidden
 */
var GridCellEditStartedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridCellEditStartedEventArgsDescriptionMetadata, _super);
    function GridCellEditStartedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellEditStartedEventArgsDescriptionMetadata.b = function (a) {
        if (GridCellEditStartedEventArgsDescriptionMetadata.a == null) {
            GridCellEditStartedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellEditStartedEventArgsDescriptionMetadata.c(GridCellEditStartedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridCellEditStartedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridCellEditStartedEventArgsDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    GridCellEditStartedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("Row", "Number:int");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    GridCellEditStartedEventArgsDescriptionMetadata.d = function (a) {
        GridCellEditStartedEventArgsDescriptionMetadata.b(a);
        a.ac("GridCellEditStartedEventArgs", function () { return new GridCellEditStartedEventArgsDescription(); });
        a.ab("GridCellEditStartedEventArgs", GridCellEditStartedEventArgsDescriptionMetadata.a);
    };
    GridCellEditStartedEventArgsDescriptionMetadata.$t = markType(GridCellEditStartedEventArgsDescriptionMetadata, 'GridCellEditStartedEventArgsDescriptionMetadata');
    GridCellEditStartedEventArgsDescriptionMetadata.a = null;
    return GridCellEditStartedEventArgsDescriptionMetadata;
}(Base));
export { GridCellEditStartedEventArgsDescriptionMetadata };
